const path = require('path');
const entryProvider = require('../../utilities/entry-provider');
const {ProvidePlugin} = require('webpack');
const DeadCodePlugin = require('webpack-deadcode-plugin');

const commonChunkName = 'webpack-runtime';


module.exports = {
    name: "JavaScript",
    entry: entryProvider.getEntries('./front/entry/js/', '**/*.js'),
    output: {
        path: path.resolve('./front/build/js'),
        filename: '[name].js'
    },

    resolve: {
        extensions: ['.js'],
        modules: [
            'theme',
            'node_modules'
        ],
        alias: {
            "jquery": path.resolve('./node_modules/jquery/dist/jquery.js'),
            "inputmask.dependencyLib": path.resolve('./node_modules/inputmask/dist/inputmask/inputmask.dependencyLib.jquery.js'),
            "inputmask.binding": path.resolve('./node_modules/inputmask/dist/inputmask/bindings/inputmask.binding.js'),
            "jquery.inputmask": path.resolve('./node_modules/inputmask/dist/inputmask/jquery.inputmask.js'),
        }
    },
    module: {
        rules: [{
            test: /\.js$/,
            use: {
                loader: 'babel-loader',
                options: {
                    presets: ["@babel/env"],
                    plugins: ['transform-remove-strict-mode', '@babel/proposal-class-properties'],
                }
            },

        }, {
            test: /\.(png|jpg|jpeg|gif|svg|swf)$/,
            loader: 'file-loader',
            options: {
                name: '[path][name]-[hash].[ext]',
                outputPath: '../assets',
                publicPath: '/front/build/assets/'
            },
        }]
    },
    plugins: [
        new DeadCodePlugin({
            detectUnusedExport: false,
            patterns: [
                'front/src/**/*.js',
                'theme/**/*.js',
            ],
            exclude: [
                '**/theme/layout/**',
            ],
        }),
        new ProvidePlugin({
            $: "jquery",
            jQuery: "jquery"
        })
    ],
    optimization: {
        runtimeChunk: {
            name: commonChunkName
        },
        splitChunks: {
            cacheGroups: {
                [commonChunkName]: {
                    name: commonChunkName,
                    chunks: 'initial',
                    minChunks: 2
                }
            }
        }
    }
};