const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const OptimizeCssAssetsPlugin = require('optimize-css-assets-webpack-plugin');
const path = require('path');
const entryProvider = require('../../utilities/entry-provider');

const cssLoader = {
    loader: 'css-loader',
    options: {
        importLoaders: 1,
        sourceMap: true
    }
};

const lessLoader = {
    loader: 'less-loader',
    options: {
        sourceMap: true
    }
};

module.exports = {
    name: "Styles",
    entry: entryProvider.getEntries('./front/entry/css/', '**/*.js'),
    output: {
        path: path.resolve('./front/build/css'),
        filename: '../css2js/[name].js'
    },
    stats: {children: false},
    optimization : {
        minimizer: [
            new OptimizeCssAssetsPlugin()
        ]
    },
    module: {
        rules: [
            {
                test: /\.(css|less)$/,
                use: [MiniCssExtractPlugin.loader, cssLoader, lessLoader],

            },
            {
                test: /\.(png|jpg|jpeg|gif|svg|eot|woff|woff2|ttf)$/,
                loader: 'file-loader',
                options: {
                    name: '[path][name]-[hash].[ext]',
                    outputPath: '../assets',
                    publicPath: '/front/build/assets/'
                },
            },
        ],

    },
    plugins: [
        new MiniCssExtractPlugin()
    ]
};