const path = require('path');

const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const entry = require('webpack-glob-entry');
const babelConfig = require('./babel.config');

const isDev = process.env.NODE_ENV === 'development' || process.env.NODE_ENV === undefined;
const componentsSrc = '@skbkontur/ws-components/src';

const babelRule = {
    test: /\.(js|jsx)$/,
    use: {
        loader: 'babel-loader',
        options: babelConfig
    }
};

const assetsRule = {
    test: /\.(ttf|eot|woff2?|png|jpe?g|gif|svg)$/,
    loader: 'file-loader',
    options: {
        outputPath: '../../assets',
        name: '[name]-[hash].[ext]',
        publicPath: '/front/build/assets/'
    }
};

const styleRule = (isLess) => ({
    test: isLess ? /\.less$/ : /\.(css|scss)$/,
    use: [
        MiniCssExtractPlugin.loader,
        {
            loader: 'css-loader',
            options: {
                modules: true,
                localIdentName: '[name]__[local]__[hash:base64:5]'
            }
        },
        'resolve-url-loader',
        'postcss-loader',
        {
            loader: isLess ? 'less-loader' : 'sass-loader',
            options: {
                sourceMap: true
            }
        }
    ]
});

const base = {
    mode: isDev ? 'development' : 'production',
    output: {
        libraryTarget: 'umd',
        globalObject: '(typeof window !== \'undefined\' ? window : this)', //NOTE: https://github.com/webpack/webpack/issues/6522
        path: path.resolve('./front/build/js/react'),
        filename: '[name].js',
        publicPath: '/front/build/js/react'
    }
};

const vendors = {
    entry: {
        common: './front/entry/react/common'
    }
};

const defaultEntries = {
    entry: entry('./front/entry/react/!(common).js'),
    plugins: [
        new MiniCssExtractPlugin({
            filename: '../../css/react/[name].css',
            chunkFilename: '[id].css'
        })
    ],
    module: {
        rules: [
            babelRule,
            styleRule(true),
            styleRule(false),
            assetsRule
        ]
    },
    externals: {
        'react': 'React',
        'react-dom': 'ReactDOM'
    },
    resolve: {
        extensions: ['.js', '.jsx', '.json'],
        alias: {
            components: `${componentsSrc}/components`,
            common: `${componentsSrc}/common`
        },
        symlinks: false
    }
};

module.exports = [
    Object.assign(defaultEntries, base),
    Object.assign(vendors, base)
];